@@ -31,3 +31,24 @@ class ListTagResourcesRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ResourceIds(self): # RepeatList
+		return self.get_body_params().get('ResourceId')
+
+	def set_ResourceIds(self, ResourceId):  # RepeatList
+		for depth1 in range(len(ResourceId)):
+			self.add_body_params('ResourceId.' + str(depth1 + 1), ResourceId[depth1])
+	def get_ResourceType(self): # String
+		return self.get_body_params().get('ResourceType')
+
+	def set_ResourceType(self, ResourceType):  # String
+		self.add_body_params('ResourceType', ResourceType)
+	def get_NextToken(self): # String
+		return self.get_body_params().get('NextToken')
+
+	def set_NextToken(self, NextToken):  # String
+		self.add_body_params('NextToken', NextToken)
+	def get_Tag(self): # String
+		return self.get_body_params().get('Tag')
+
+	def set_Tag(self, Tag):  # String
+		self.add_body_params('Tag', Tag)
